module UU
  module OS
    module Env
      module Process

        # Enumeration with process event types.
        class ProcessEventType

          # Informational process event.
          # Should be used for reporting of important events in
          # process lifecycle. Other processes can listen to this
          # type of event.
          ACTIVE_INFO='ACTIVE_INFO'

          # Warning process event.
          # Should be used for reporting of unexpected problems
          # which can be handled without direct user interaction.
          # Other processes can listen to this type of event.
          ACTIVE_WARNING='ACTIVE_WARNING'

          # Progress process event.
          # Should be used for common reporting of process progress.
          # Unlike other types progress event type is mostly used only
          # for sending information to user and cannot be used for
          # interaction with other processes.
          ACTIVE_PROGRESS='ACTIVE_PROGRESS'

          # Completed process event.
          # Using this type of event marks process as completed. No
          # other events should be used after this event is fired.
          # If propagation of process event to activity is enabled,
          # using of this event cause activity to end in non-final
          # state.
          COMPLETED='COMPLETED'

          # Completed with warning process event.
          # Using this type of event marks process as completed but
          # with minor problems which are not fatal to process. No
          # other events should be used after this event is fired.
          COMPLETED_WITH_WARNING='COMPLETED_WITH_WARNING'

          # Completed with error process event.
          # Using this type of event marks process as failed due to
          # some serious problems which are blocking process from
          # being completed. No other events should be used after
          # this event is fired.
          COMPLETED_WITH_ERROR='COMPLETED_WITH_ERROR'

        end

      end
    end
  end
end
